#!/bin/bash
server_url=$1
deploy_key=$2

if [ $# -lt 2 ]
    then
        echo "Wrong number of arguments supplied."
        echo "Usage: $0 <server_url> <deploy_key>."
        exit 1
fi

register(){
server_url=$1
deploy_key=$2
honeypot=$3
hostname=$(hostname)

curl -s -X POST -H "Content-Type: application/json" -d "{
        \"name\": \"${hostname}-${honeypot}\", 
        \"hostname\": \"$hostname\", 
        \"deploy_key\": \"$deploy_key\",
        \"honeypot\": \"$honeypot\"
}" $server_url/api/sensor/ > /tmp/deploy.json

uuid=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["uuid"]')

if [ -z "$uuid" ]
    then
        echo "Could not create sensor using name \"$hostname\"."
        exit 1
fi

set -e

echo "Created sensor: " $uuid

######################################################
# hpfeeds info
export HPF_HOST=$(echo $server_url | sed 's#^http://##; s#^https://##; s#/.*$##; s/:.*$//')
export HPF_PORT="10000"
export HPF_IDENT=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["identifier"]')
export HPF_SECRET=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["secret"]')
######################################################
}

register $server_url $deploy_key "elastichoney"


# Setup HPFeeds
sed -i "/\"hpfeeds\": {/,/\}\,/ s/\"enabled\":.*/\"enabled\": true,/" /usr/share/elastichoney/config.json
sed -i "/\"hpfeeds\": {/,/\}\,/ s/\"host\":.*/\"host\": \"$HPF_HOST\",/" /usr/share/elastichoney/config.json
sed -i "/\"hpfeeds\": {/,/\}\,/ s/\"port\":.*/\"port\": $HPF_PORT,/" /usr/share/elastichoney/config.json
sed -i "/\"hpfeeds\": {/,/\}\,/ s/\"ident\":.*/\"ident\": \"$HPF_IDENT\",/" /usr/share/elastichoney/config.json
sed -i "/\"hpfeeds\": {/,/\}\,/ s/\"secret\":.*/\"secret\": \"$HPF_SECRET\",/" /usr/share/elastichoney/config.json

systemctl restart elastichoney

